==> react-lds-8.7.0.tgz: package/es/components/Grid/Column.js <==
import "core-js/modules/es7.object.get-own-property-descriptors";
import "core-js/modules/es6.object.assign";
import "core-js/modules/es6.symbol";
import "core-js/modules/web.dom.iterable";
import "core-js/modules/es6.array.iterator";
import "core-js/modules/es6.object.to-string";
import "core-js/modules/es6.object.keys";
import "core-js/modules/es6.regexp.split";
import "core-js/modules/es6.string.iterator";
import "core-js/modules/es6.array.from";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { keys.push.apply(keys, Object.getOwnPropertySymbols(object)); } if (enumerableOnly) keys = keys.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(source, true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(source).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import omit from 'lodash-es/omit';
import { applyDecorators, decoratorProp } from '../../utils';
var validBreakpoints = ['small', 'medium', 'large', 'max-small', 'max-medium', 'max-large'];

var breakPointProp = function breakPointProp(breakpoint, suffix) {
  return "".concat(breakpoint, "-").concat(suffix);
};

var sizeRegex = /^([1-9]|1[0-2])-([1-9]|1[0-2])$/;
var orderRegex = /^((1[0,1,2])|[1-9])$/;

var Column = function Column(props) {
  var El = props.as,
      children = props.children,
      className = props.className,
      flavor = props.flavor,
      variation = props.variation,
      omitCol = props.omitCol,
      rest = _objectWithoutProperties(props, ["as", "children", "className", "flavor", "variation", "omitCol"]);

  var sldsClasses = [className, {
    'slds-col': !omitCol
  }, applyDecorators(variation)];
  var breakpoints = Array.from(validBreakpoints);
  breakpoints.unshift('');
  var generatedProps = [];
  breakpoints.forEach(function (breakpoint) {
    var emptyBreakPoint = breakpoint === '';
    var sizePropName = emptyBreakPoint ? 'sizeOf' : breakPointProp(breakpoint, 'sizeOf');
    var sizeString = emptyBreakPoint ? 'size' : "".concat(breakpoint, "-size");
    var size = props[sizePropName];

    if (size && sizeRegex.test(size)) {
      var from = parseInt(size.split('-')[0], 10);
      var to = parseInt(size.split('-')[1], 10);
      sldsClasses.push("slds-".concat(sizeString, "_").concat(from, "-of-").concat(to));
    }

    var orderPropName = emptyBreakPoint ? 'order' : breakPointProp(breakpoint, 'order');
    var orderString = emptyBreakPoint ? 'order' : "".concat(breakpoint, "-order");
    var order = props[orderPropName];

    if (order && orderRegex.test(order)) {
      var position = parseInt(order.split('-')[0], 10);
      sldsClasses.push("slds-".concat(orderString, "_").concat(position));
    }

    generatedProps.push(sizePropName, orderPropName);
  });
  var restProps = omit(rest, generatedProps);
  return React.createElement(El, _extends({}, restProps, {
    className: cx(sldsClasses)
  }), children);
};

var sizeOfPropType = process.env.NODE_ENV !== "production" ? function (props, propName) {
  var size = props[propName]; // eslint-disable-line react/destructuring-assignment

  if (size && typeof size !== 'string') {
    return new Error("".concat(propName, " must be a string"));
  }

  if (typeof size === 'string' && !sizeRegex.test(size)) {
    return new Error("".concat(propName, " must be of format {1-12}-{1-12}"));
  }

  if (sizeRegex.test(size)) {
    var from = parseInt(size.split('-')[0], 10);
    var to = parseInt(size.split('-')[1], 10);

    if (from > to) {
      return new Error("".concat(propName, " ").concat(size, " is impossible. `").concat(from, "` needs to be smaller than `").concat(to, "`"));
    }
  }

  return null;
} : {};
var orderPropType = process.env.NODE_ENV !== "production" ? function (props, propName) {
  var position = props[propName]; // eslint-disable-line react/destructuring-assignment

  if (position && !(typeof position === 'string' || typeof position === 'number')) {
    return new Error("".concat(propName, " must be a string or a number"));
  }

  if ((typeof position === 'string' || typeof position === 'number') && !orderRegex.test(position)) {
    return new Error("".concat(propName, " must be of format {1-12}"));
  }

  return null;
} : {};
Column.defaultProps = {
  as: 'div',
  className: null,
  variation: [],
  omitCol: false
};
Column.propTypes = process.env.NODE_ENV !== "production" ? _objectSpread({
  /**
   * Allows using an arbitrary DOM element as container
   */
  as: PropTypes.string,

  /**
   * Column content
   */
  children: PropTypes.node.isRequired,

  /**
   * (Optional) class name. Usually used to apply `slds-p_horizontal` classes
   */
  className: PropTypes.string,

  /*
   * variation: string or array of strings. Variations: has-flexi-truncate,
   * no-flex, no-space, grow, grow-none, shrink, shrink-none
   */
  variation: decoratorProp(['has-flexi-truncate', 'no-flex', 'no-space', 'grow', 'grow-none', 'shrink', 'shrink-none']),

  /**
   * omit 'slds-col'
   */
  omitCol: PropTypes.bool,

  /**
   * sizeOf: specify size in fractions like 1-2, 4-12. Breakpoint possible e.g. small-sizeOf="1-2"
   */
  sizeOf: sizeOfPropType
}, validBreakpoints.reduce(function (_propTypes, breakpoint) {
  // this generates sizeOf props for each of the valid breakpoints
  var propTypes = _propTypes;
  propTypes[breakPointProp(breakpoint, 'sizeOf')] = sizeOfPropType;
  return propTypes;
}, {}), {
  /**
   * order: reorder columns with number from 1 to 12. Breakpoint possible e.g. medium-order="3"
   */
  order: orderPropType
}, validBreakpoints.reduce(function (_propTypes, breakpoint) {
  // this generates order props for each of the valid breakpoints
  var propTypes = _propTypes;
  propTypes[breakPointProp(breakpoint, 'order')] = orderPropType;
  return propTypes;
}, {})) : {};
export default Column;

==> react-lds-9.1.0.tgz: package/es/components/Grid/Column.js <==
import "core-js/modules/es.symbol";
import "core-js/modules/es.array.concat";
import "core-js/modules/es.array.filter";
import "core-js/modules/es.array.for-each";
import "core-js/modules/es.array.from";
import "core-js/modules/es.array.index-of";
import "core-js/modules/es.array.reduce";
import "core-js/modules/es.object.assign";
import "core-js/modules/es.object.get-own-property-descriptor";
import "core-js/modules/es.object.get-own-property-descriptors";
import "core-js/modules/es.object.keys";
import "core-js/modules/es.parse-int";
import "core-js/modules/es.regexp.exec";
import "core-js/modules/es.string.iterator";
import "core-js/modules/es.string.split";
import "core-js/modules/web.dom-collections.for-each";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import omit from 'lodash-es/omit';
import { applyDecorators, decoratorProp } from '../../utils';
var validBreakpoints = ['small', 'medium', 'large', 'max-small', 'max-medium', 'max-large'];

var breakPointProp = function breakPointProp(breakpoint, suffix) {
  return "".concat(breakpoint, "-").concat(suffix);
};

var sizeRegex = /^([1-9]|1[0-2])-([1-9]|1[0-2])$/;
var orderRegex = /^((1[0,1,2])|[1-9])$/;

var Column = function Column(props) {
  var El = props.as,
      children = props.children,
      className = props.className,
      flavor = props.flavor,
      variation = props.variation,
      omitCol = props.omitCol,
      rest = _objectWithoutProperties(props, ["as", "children", "className", "flavor", "variation", "omitCol"]);

  var sldsClasses = [className, {
    'slds-col': !omitCol
  }, applyDecorators(variation)];
  var breakpoints = Array.from(validBreakpoints);
  breakpoints.unshift('');
  var generatedProps = [];
  breakpoints.forEach(function (breakpoint) {
    var emptyBreakPoint = breakpoint === '';
    var sizePropName = emptyBreakPoint ? 'sizeOf' : breakPointProp(breakpoint, 'sizeOf');
    var sizeString = emptyBreakPoint ? 'size' : "".concat(breakpoint, "-size");
    var size = props[sizePropName];

    if (size && sizeRegex.test(size)) {
      var from = parseInt(size.split('-')[0], 10);
      var to = parseInt(size.split('-')[1], 10);
      sldsClasses.push("slds-".concat(sizeString, "_").concat(from, "-of-").concat(to));
    }

    var orderPropName = emptyBreakPoint ? 'order' : breakPointProp(breakpoint, 'order');
    var orderString = emptyBreakPoint ? 'order' : "".concat(breakpoint, "-order");
    var order = props[orderPropName];

    if (order && orderRegex.test(order)) {
      var position = parseInt(order.split('-')[0], 10);
      sldsClasses.push("slds-".concat(orderString, "_").concat(position));
    }

    generatedProps.push(sizePropName, orderPropName);
  });
  var restProps = omit(rest, generatedProps);
  return React.createElement(El, _extends({}, restProps, {
    className: cx(sldsClasses)
  }), children);
};

var sizeOfPropType = process.env.NODE_ENV !== "production" ? function (props, propName) {
  var size = props[propName]; // eslint-disable-line react/destructuring-assignment

  if (size && typeof size !== 'string') {
    return new Error("".concat(propName, " must be a string"));
  }

  if (typeof size === 'string' && !sizeRegex.test(size)) {
    return new Error("".concat(propName, " must be of format {1-12}-{1-12}"));
  }

  if (sizeRegex.test(size)) {
    var from = parseInt(size.split('-')[0], 10);
    var to = parseInt(size.split('-')[1], 10);

    if (from > to) {
      return new Error("".concat(propName, " ").concat(size, " is impossible. `").concat(from, "` needs to be smaller than `").concat(to, "`"));
    }
  }

  return null;
} : {};
var orderPropType = process.env.NODE_ENV !== "production" ? function (props, propName) {
  var position = props[propName]; // eslint-disable-line react/destructuring-assignment

  if (position && !(typeof position === 'string' || typeof position === 'number')) {
    return new Error("".concat(propName, " must be a string or a number"));
  }

  if ((typeof position === 'string' || typeof position === 'number') && !orderRegex.test(position)) {
    return new Error("".concat(propName, " must be of format {1-12}"));
  }

  return null;
} : {};
Column.defaultProps = {
  as: 'div',
  className: null,
  variation: [],
  omitCol: false
};
Column.propTypes = process.env.NODE_ENV !== "production" ? _objectSpread({
  /**
   * Allows using an arbitrary DOM element as container
   */
  as: PropTypes.string,

  /**
   * Column content
   */
  children: PropTypes.node.isRequired,

  /**
   * (Optional) class name. Usually used to apply `slds-p_horizontal` classes
   */
  className: PropTypes.string,

  /*
   * variation: string or array of strings. Variations: has-flexi-truncate,
   * no-flex, no-space, grow, grow-none, shrink, shrink-none
   */
  variation: decoratorProp(['has-flexi-truncate', 'no-flex', 'no-space', 'grow', 'grow-none', 'shrink', 'shrink-none']),

  /**
   * omit 'slds-col'
   */
  omitCol: PropTypes.bool,

  /**
   * sizeOf: specify size in fractions like 1-2, 4-12. Breakpoint possible e.g. small-sizeOf="1-2"
   */
  sizeOf: sizeOfPropType
}, validBreakpoints.reduce(function (_propTypes, breakpoint) {
  // this generates sizeOf props for each of the valid breakpoints
  var propTypes = _propTypes;
  propTypes[breakPointProp(breakpoint, 'sizeOf')] = sizeOfPropType;
  return propTypes;
}, {}), {
  /**
   * order: reorder columns with number from 1 to 12. Breakpoint possible e.g. medium-order="3"
   */
  order: orderPropType
}, validBreakpoints.reduce(function (_propTypes, breakpoint) {
  // this generates order props for each of the valid breakpoints
  var propTypes = _propTypes;
  propTypes[breakPointProp(breakpoint, 'order')] = orderPropType;
  return propTypes;
}, {})) : {};
export default Column;
